@@ -1,8 +1,5 @@
 package Dist::Zilla::Plugin::TemplateXS;
-{
-  $Dist::Zilla::Plugin::TemplateXS::VERSION = '0.002';
-}
-
+$Dist::Zilla::Plugin::TemplateXS::VERSION = '0.003';
 use Moose;
 with qw(Dist::Zilla::Role::FileGatherer Dist::Zilla::Role::TextTemplate);
 
@@ -70,7 +67,7 @@ Dist::Zilla::Plugin::TemplateXS - A simple xs-file-from-template plugin
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -80,7 +77,7 @@ version 0.002
 
 =head1 DESCRIPTION
 
-This is a L<ModuleMaker|Dist::Zilla::Role::ModuleMaker> used for creating new XS files when minting a new dist with C<dzil new>. It uses L<Text::Template> (via L<Dist::Zilla::Role::TextTemplate>) to render a template into a XS file. The template is given three variables for use in rendering: C<$name>, the module name; C<$dist>, the Dist::Zilla object, and C<$style>, the C<style> attribute that determines the location of the new file.
+This is a L<FileGatherer|Dist::Zilla::Role::FileGatherer> used for creating new XS files when minting a new dist with C<dzil new>. It uses L<Text::Template> (via L<Dist::Zilla::Role::TextTemplate>) to render a template into a XS file. The template is given three variables for use in rendering: C<$name>, the module name; C<$dist>, the Dist::Zilla object, and C<$style>, the C<style> attribute that determines the location of the new file.
 
 =head1 ATTRIBUTES
 
